package com.ruoyi.inventory.service;
import com.ruoyi.inventory.domain.HealthcareInventoryDrugoutType;

import java.util.List;

/**
 * 仓库调拨记录Service接口
 *
 * @author ruoyi
 * @date 2024-10-08
 */
public interface IHealthcareInventoryDrugoutTypeService
{
    /**
     * 查询仓库调拨记录
     *
     * @param outTypeId 仓库调拨记录主键
     * @return 仓库调拨记录
     */
    public HealthcareInventoryDrugoutType selectHealthcareInventoryDrugoutTypeByOutTypeId(Long outTypeId);

    /**
     * 查询仓库调拨记录
     *
     * @param DrugOutId 出库记录Id
     * @return 仓库调拨记录
     */
    public HealthcareInventoryDrugoutType selectHealthcareInventoryDrugoutTypeByOutTypeDrugOutId(Long DrugOutId);

    /**
     * 查询仓库调拨记录列表
     *
     * @param healthcareInventoryDrugoutType 仓库调拨记录
     * @return 仓库调拨记录集合
     */
    public List<HealthcareInventoryDrugoutType> selectHealthcareInventoryDrugoutTypeList(HealthcareInventoryDrugoutType healthcareInventoryDrugoutType);

    /**
     * 新增仓库调拨记录
     *
     * @param healthcareInventoryDrugoutType 仓库调拨记录
     * @return 结果
     */
    public int insertHealthcareInventoryDrugoutType(HealthcareInventoryDrugoutType healthcareInventoryDrugoutType);

    /**
     * 修改仓库调拨记录
     *
     * @param healthcareInventoryDrugoutType 仓库调拨记录
     * @return 结果
     */
    public int updateHealthcareInventoryDrugoutType(HealthcareInventoryDrugoutType healthcareInventoryDrugoutType);

    /**
     * 批量删除仓库调拨记录
     *
     * @param outTypeIds 需要删除的仓库调拨记录主键集合
     * @return 结果
     */
    public int deleteHealthcareInventoryDrugoutTypeByOutTypeIds(Long[] outTypeIds);

    /**
     * 删除仓库调拨记录信息
     *
     * @param outTypeId 仓库调拨记录主键
     * @return 结果
     */
    public int deleteHealthcareInventoryDrugoutTypeByOutTypeId(Long outTypeId);
}
